<template>
  <div class="bg-white">
    <div class="max-w-7xl mx-auto py-16 px-4 sm:px-6 lg:pt-24 lg:px-8">
      <div class="max-w-5xl mx-auto text-center">
        <h2 class="text-3xl font-extrabold text-gray-900">پرسش های متداول</h2>
      </div>
      <dl class="max-w-2xl mt-12 mx-auto">
        <div>
          <div class="sm:hidden">
            <label for="tabs" class="sr-only">Select a tab</label>
            <!-- Use an "onChange" listener to redirect the user to the selected tab URL. -->
            <select
              id="tabs"
              name="tabs"
              class="block w-full focus:ring-indigo-500 focus:border-indigo-500 border-gray-300 rounded-md"
            >
              <option
                v-for="tab in tabs"
                :key="tab.name"
                :selected="tab.current"
              >
                {{ tab.name }}
              </option>
            </select>
          </div>
          <div class="hidden sm:block">
            <div class="border-b border-gray-200 mb-12">
              <nav
                class="-mb-px flex"
                aria-label="Tabs"
                id="myTab"
                data-tabs-toggle="#myTabContent"
                role="tablist"
              >
                <button
                  v-for="(tab, index) in tabs"
                  @click="changeTab(index)"
                  :key="tab.name"
                  :id="tab.id"
                  :aria-selected="tab.aria_selected"
                  :aria-controls="tab.aria_controls"
                  :role="tab.role"
                  :data-tabs-target="tab.data_tabs_target"
                  :class="[
                    tab.current
                      ? 'border-red-500 text-red-500'
                      : 'border-transparent text-gray-500 hover:text-gray-700 hover:border-gray-300',
                    'w-1/4 py-4 px-1 text-center border-b-2 font-medium text-sm',
                  ]"
                  :aria-current="tab.current ? 'page' : undefined"
                >
                  {{ tab.name }}
                </button>

                <!-- <div v-for="post in tabs[tabIndex].post">
                  {{ post.question }}
                </div> -->
              </nav>
            </div>
            
            <div
              v-show="showtabs"
              class="my-5 "
              v-for="(post, index) in tabs[tabIndex].post"
            >
              <fieldset>
                <legend class="sr-only">Server size</legend>
                <div class="">
                  <!--
      Checked: "border-transparent", Not Checked: "border-gray-300"
      Active: "ring-2 ring-indigo-500"
    -->
                  <label
                  :class="{'rounded-t-xl':post.current ,'rounded-xl': !post.current  }"
                    class="relative block bg-white border-0  shadow-inner px-6 py-4 cursor-pointer sm:flex sm:justify-between focus:outline-none"
                  >
                    <input
                      type="radio"
                      name="server-size"
                      value="Hobby"
                      class="sr-only"
                      aria-labelledby="server-size-0-label"
                      aria-describedby="server-size-0-description-0 server-size-0-description-1"
                    />
                    <div class="flex items-center">
                      <div class="text-sm">
                        <p
                          id="server-size-0-label"
                          class="font-medium text-gray-900"
                        >
                          {{ post.question }}
                        </p>
                      </div>
                    </div>
                    <div
                      id="server-size-0-description-1"
                      class="mt-2 flex text-sm sm:mt-0 sm:block sm:ml-4 sm:text-right"
                    >
                      <img
                        v-show="!post.current"
                        @click="showTabAnswer(index)"
                        src="shape.svg"
                        alt=""
                        srcset=""
                      />
                      <!-- <img
                        v-show="post.current"
                        @click="showTabAnswer(index)"
                        class="bg-red"
                        src="incorrect.svg"
                        alt=""
                        srcset=""
                      /> -->
                    </div>
                    <!--
        Active: "border", Not Active: "border-2"
        Checked: "border-indigo-500", Not Checked: "border-transparent"
      -->
                    <!-- <div
                      class="absolute -inset-px rounded-lg border-0 pointer-events-none"
                      aria-hidden="true"
                    ></div> -->
                  </label>

                  <label
                    v-show="post.current"
                    :id="post.id"
                    class="relative block bg-[#F8F6F6] border-0 rounded-b-lg  px-6 py-4 cursor-pointer sm:flex sm:justify-between focus:outline-none"
                  >
                    <input
                      type="radio"
                      name="server-size"
                      value="Hobby"
                      class="sr-only"
                      aria-labelledby="server-size-1-label"
                      aria-describedby="server-size-0-description-0 server-size-0-description-1"
                    />
                    <div class="flex items-center">
                      <div class="text-sm">
                        <p
                          id="server-size-1-label"
                          class="font-medium text-gray-900"
                        >
                          {{ post.answer }}
                        </p>
                      </div>
                    </div>

                    <!--
        Active: "border", Not Active: "border-2"
        Checked: "border-indigo-500", Not Checked: "border-transparent"
      -->
                    <!-- <div
                      class="absolute -inset-px rounded-lg border-0 pointer-events-none"
                      aria-hidden="true"
                    ></div> -->
                  </label>
                </div>
              </fieldset>
            </div>
          </div>
        </div>
      </dl>
      <div class="max-w-5xl mx-auto text-center mt-12">
        <h2 class="text-3xl font-extrabold text-gray-900">اگر پاسخ پرسش خود را پیدا نکرده اید؟
        </h2>
        <div class="my-5 ">
          <nuxt-link to="contact-us"
            class="block w-1/3 pink_white_gradient font-yekanBakh mx-auto py-4 px-4 rounded-full shadow-sm text-lg font-medium text-black hover:bg-red-400 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-[#ffc8c3]"
          > به ما پیام بدهید
          </nuxt-link>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import tabs from '@/data/faq/tab.json'
export default {
  data() {
    return {
      tabs,
      tabIndex: 0,
      showtabs: false,
      hasError:false
    }
  },
  mounted () {
   this.changeTab(0) ;
  },
  methods: {
    changeTab(index) {
      this.tabIndex = index
      for (var i = 0; i < this.tabs.length; i++) {
        if (i != index) this.tabs[i].current = false
      }
    //   if (this.tabs[index].current == true) {
    //     this.tabs[index].current = false
    //     this.showtabs = false
    //   } else {
        this.tabs[index].current = true
        this.showtabs = true
    //   }
      for (var i = 0; i < this.tabs[index].post.length; i++) {
        this.tabs[index].post[i].current = false
      }
    },
    showTabAnswer(index) {
     
            for (var i=0; i<this.tabs[this.tabIndex].post.length; i++){
          this.tabs[this.tabIndex].post[i].current = false;
        }
         this.tabs[this.tabIndex].post[index].current =
        !this.tabs[this.tabIndex].post[index].current

    },
  },
}
</script>

<style lang="scss" scoped></style>
